@@ -1,3 +1,4 @@
+import re
 from six import string_types
 from ....abstract_type_builder import AbstractTypeBuilder
 from graphene import Enum
@@ -23,7 +24,8 @@ class EnumType(AbstractTypeBuilder):
         enum_attrs = {}
         for value, pretty in choices:
             name = value if isinstance(value, string_types) else pretty
-            enum_attrs[name.replace(" ", "_").replace("-", "_")] = value
+            deburred_name = re.sub(r'\W+', '', name.replace(" ", "_").replace("-", "_"))
+            enum_attrs[deburred_name] = value
 
         camel_case = "".join([part.capitalize() for part in field.name.split("_")])
         return type(
