@@ -1,4 +1,5 @@
 from graphene import Int, List, Argument, Boolean
+from graphql.pyutils import Undefined
 from six import iteritems
 from django.conf import settings
 from django.db.models import Q
@@ -14,11 +15,11 @@ ABSOLUTE_MAXIMUM_RESULTS = SCHEMA_BUILDER_SETTINGS.get("ABSOLUTE_MAXIMUM_RESULTS
 
 def create_query_arguments(where_type, order_by_type):
     return {
-        "where": Argument(where_type),
-        "order_by": Argument(List(order_by_type)),
-        "limit": Argument(Int),
-        "offset": Argument(Int),
-        "distinct": Argument(Boolean),
+        "where": Argument(where_type, default_value=Undefined),
+        "order_by": Argument(List(order_by_type), default_value=Undefined),
+        "limit": Argument(Int, default_value=Undefined),
+        "offset": Argument(Int, default_value=Undefined),
+        "distinct": Argument(Boolean, default_value=Undefined),
     }
 
 
@@ -36,7 +37,7 @@ def update_queryset_based_on_arguments(queryset, args, take_slice=True):
             sort_key = sort_keys[0]
             sort_values = list(sort_entry.values())
             sort_direction = sort_values[0]
-            dash = "" if sort_direction == "ascending" else "-"
+            dash = "" if sort_direction.value == "ascending" else "-"
             sort_order.append("{}{}".format(dash, sort_key))
         queryset = queryset.order_by(*sort_order)
 
@@ -70,29 +71,45 @@ def filter_from_where_args(where_args, annotations, _and=True):
 
         # Predicate operations
         if "_eq" in value:
-            combined_qs.append(Q(**{key: value["_eq"]}))
+            combined_qs.append(Q(**{key: get_raw_value(value["_eq"])}))
         if "_neq" in value:
-            combined_qs.append(~Q(**{key: value["_neq"]}))
+            combined_qs.append(~Q(**{key: get_raw_value(value["_neq"])}))
         if "_gt" in value:
-            combined_qs.append(Q(**{"{}__gt".format(key): value["_gt"]}))
+            combined_qs.append(Q(**{"{}__gt".format(key): get_raw_value(value["_gt"])}))
         if "_gte" in value:
-            combined_qs.append(Q(**{"{}__gte".format(key): value["_gte"]}))
+            combined_qs.append(
+                Q(**{"{}__gte".format(key): get_raw_value(value["_gte"])})
+            )
         if "_lt" in value:
-            combined_qs.append(Q(**{"{}__lt".format(key): value["_lt"]}))
+            combined_qs.append(Q(**{"{}__lt".format(key): get_raw_value(value["_lt"])}))
         if "_lte" in value:
-            combined_qs.append(Q(**{"{}__lte".format(key): value["_lte"]}))
+            combined_qs.append(
+                Q(**{"{}__lte".format(key): get_raw_value(value["_lte"])})
+            )
         if "_in" in value:
-            combined_qs.append(Q(**{"{}__in".format(key): value["_in"]}))
+            combined_qs.append(Q(**{"{}__in".format(key): get_raw_value(value["_in"])}))
         if "_nin" in value:
-            combined_qs.append(~Q(**{"{}__in".format(key): value["_nin"]}))
+            combined_qs.append(
+                ~Q(**{"{}__in".format(key): get_raw_value(value["_nin"])})
+            )
         if "_is_null" in value:
-            combined_qs.append(Q(**{"{}__isnull".format(key): value["_is_null"]}))
+            combined_qs.append(
+                Q(**{"{}__isnull".format(key): get_raw_value(value["_is_null"])})
+            )
         if "_like" in value:
-            combined_qs.append(Q(**{"{}__contains".format(key): value["_like"]}))
+            combined_qs.append(
+                Q(**{"{}__contains".format(key): get_raw_value(value["_like"])})
+            )
         if "_ilike" in value:
             annotations["{}_lower".format(key)] = Lower(key)
             combined_qs.append(
-                Q(**{"{}_lower__icontains".format(key): value["_ilike"].lower()})
+                Q(
+                    **{
+                        "{}_lower__icontains".format(key): get_raw_value(
+                            value["_ilike"]
+                        ).lower()
+                    }
+                )
             )
 
     if not combined_qs:
@@ -110,3 +127,10 @@ def filter_from_where_args(where_args, annotations, _and=True):
 
     # Join them all together using ANDs or ORs.
     return reduce(lambda result, q: q & result if _and else q | result, combined_qs)
+
+
+def get_raw_value(value):
+    if hasattr(value, "value"):
+        return value.value
+
+    return value
