@@ -1,7 +1,9 @@
+from six import iteritems
+from graphene import VERSION
 from graphql.language.visitor import Visitor
 from graphene.utils.str_converters import to_snake_case
 from djraphql.django_models import get_field_by_name
-from graphql.execution.base import get_field_def
+from graphql.execution.execute import get_field_def
 from graphql.execution.values import get_argument_values
 
 
@@ -18,7 +20,7 @@ class QueryFieldsVisitor(Visitor):
             gql_type = gql_type.of_type
         return gql_type
 
-    def enter_Field(
+    def enter_field(
         self,
         node,
         key,
@@ -32,17 +34,17 @@ class QueryFieldsVisitor(Visitor):
         # Get a dictionary of the arguments associated with this field
         field_def = get_field_def(self.info.schema, parent_gql_type, node.name.value)
         arguments = get_argument_values(
-            field_def.args,
-            node.arguments,
+            field_def,
+            node,
             self.info.variable_values,
         )
 
-        # Do we call enter_field?
+        # Do we call hello_field?
         if parent_gql_type.name in self.type_lookup:
             model_class = self.type_lookup[parent_gql_type.name]["model_class"]
             field = try_get_related_field(model_class, node.name.value)
             if field:
-                self.enter_field(field, arguments, graphql_node=node)
+                self.hello_field(field, arguments, graphql_node=node)
 
         # If we're traversing a relationship (e.g., we're entering the
         # "artists" node within the "LabelsMany" query), we need to push the new
@@ -57,22 +59,22 @@ class QueryFieldsVisitor(Visitor):
             if next_gql_type.name in self.type_lookup:
                 model_class = self.type_lookup[next_gql_type.name]["model_class"]
                 if not self.model_class_stack:
-                    self.enter_optimizable_tree(model_class, arguments)
+                    self.hello_optimizable_tree(model_class, arguments)
                 self.model_class_stack.append(model_class)
 
-    def enter_optimizable_tree(self, model_class, arguments):
+    def hello_optimizable_tree(self, model_class, arguments):
         pass
 
-    def leave_optimizable_tree(self, model_class):
+    def goodbye_optimizable_tree(self, model_class):
         pass
 
-    def enter_field(self, field, arguments, graphql_node=None):
+    def hello_field(self, field, arguments, graphql_node=None):
         pass
 
-    def leave_field(self, field):
+    def goodbye_field(self, field):
         pass
 
-    def leave_Field(
+    def leave_field(
         self,
         node,
         key,
@@ -88,24 +90,24 @@ class QueryFieldsVisitor(Visitor):
             if len(self.model_class_stack) == 1:
                 # We're about to pop the last item from our model stack,
                 # that means we're exiting the optimizable tree, so call that handler.
-                self.leave_optimizable_tree(self.model_class_stack.pop())
+                self.goodbye_optimizable_tree(self.model_class_stack.pop())
             elif self.model_class_stack:
                 # There will still be items left in our model stack, we're still
-                # within the optimizable tree. In this case, call leave_field.
+                # within the optimizable tree. In this case, call goodbye_field.
                 self.model_class_stack.pop()
                 field = try_get_related_field(
                     self.model_class_stack[-1], node.name.value
                 )
                 if field:
-                    self.leave_field(field)
+                    self.goodbye_field(field)
             return
 
         # We are not traversing a relationship. If we have a non-empty
-        # model stack, we need to call the leave_field handler.
+        # model stack, we need to call the goodbye_field handler.
         if self.model_class_stack:
             field = try_get_related_field(self.model_class_stack[-1], node.name.value)
             if field:
-                self.leave_field(field)
+                self.goodbye_field(field)
 
 
 def try_get_related_field(model_class, selection_name):
